==> echo-0.2.3-sources.jar: org/accidia/echo/memcache/MemcacheAccessor.java <==
package org.accidia.echo.memcache;

import com.google.common.base.Strings;
import com.google.protobuf.Message;
import net.spy.memcached.internal.GetFuture;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Map;
import java.util.concurrent.*;

import static com.google.common.base.Preconditions.checkArgument;

public class MemcacheAccessor implements IMemcacheAccessor {
    private static final Logger logger = LoggerFactory.getLogger(MemcacheAccessor.class);
    private static final Map<MemcacheDataSource, MemcacheAccessor> instanceMap = new ConcurrentHashMap<>();
    private final MemcacheDataSource memcacheDataSource;

    protected MemcacheAccessor(final MemcacheDataSource memcacheDataSource) {
        this.memcacheDataSource = memcacheDataSource;
    }

    public static synchronized MemcacheAccessor getInstance(final MemcacheDataSource memcacheDataSource) {
        checkArgument(memcacheDataSource != null, "null datasource");
        if (!instanceMap.containsKey(memcacheDataSource)) {
            final MemcacheAccessor instance = new MemcacheAccessor(memcacheDataSource);
            instanceMap.put(memcacheDataSource, instance);
        }
        return instanceMap.get(memcacheDataSource);
    }

    @Override
    public Message get(final String key, final long timeoutMs) {
        checkArgument(!Strings.isNullOrEmpty(key), "null/empty key");
        final GetFuture<Object> futureGet = this.memcacheDataSource.getMemcachedClient().asyncGet(key);
        try {
            return (Message) futureGet.get(timeoutMs, TimeUnit.MILLISECONDS);
        } catch (Exception e) {
            logger.error("exception on async get -> ignoring and returning null ", e);
            futureGet.cancel(false);
            return null;
        }
    }

    @Override
    public void set(final String key, final int expiry, final Object value) {
        checkArgument(!Strings.isNullOrEmpty(key), "null/empty key");
        checkArgument(value != null, "null value");
        this.memcacheDataSource.getMemcachedClient().set(key, expiry, value);
    }

    @Override
    public void delete(final String key) {
        checkArgument(!Strings.isNullOrEmpty(key), "null/empty key");
        this.memcacheDataSource.getMemcachedClient().delete(key);
    }
}

==> echo-0.2.9-sources.jar: org/accidia/echo/memcache/MemcacheAccessor.java <==
package org.accidia.echo.memcache;

import com.google.common.base.Strings;
import com.google.protobuf.Message;
import net.spy.memcached.internal.GetFuture;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Map;
import java.util.concurrent.*;

import static com.google.common.base.Preconditions.checkArgument;

public class MemcacheAccessor implements IMemcacheAccessor {
    private static final Logger logger = LoggerFactory.getLogger(MemcacheAccessor.class);
    private static final Map<MemcacheDataSource, MemcacheAccessor> instanceMap = new ConcurrentHashMap<>();
    private final MemcacheDataSource memcacheDataSource;
    private final String prefix;

    protected MemcacheAccessor(final MemcacheDataSource memcacheDataSource, final String prefix) {
        this.memcacheDataSource = memcacheDataSource;
        this.prefix = prefix;
    }

    public static synchronized MemcacheAccessor getInstance(final MemcacheDataSource memcacheDataSource, final String prefix) {
        checkArgument(memcacheDataSource != null, "null datasource");
        checkArgument(!Strings.isNullOrEmpty(prefix), "null/empty prefix");
        if (!instanceMap.containsKey(memcacheDataSource)) {
            final MemcacheAccessor instance = new MemcacheAccessor(memcacheDataSource, prefix);
            instanceMap.put(memcacheDataSource, instance);
        }
        return instanceMap.get(memcacheDataSource);
    }

    @Override
    public Message get(final String key, final long timeoutMs) {
        checkArgument(!Strings.isNullOrEmpty(key), "null/empty key");
        final GetFuture<Object> futureGet = this.memcacheDataSource.getMemcachedClient().asyncGet(this.prefix + key);
        try {
            return (Message) futureGet.get(timeoutMs, TimeUnit.MILLISECONDS);
        } catch (Exception e) {
            logger.error("exception on async get -> ignoring and returning null ", e);
            futureGet.cancel(false);
            return null;
        }
    }

    @Override
    public void set(final String key, final int expiry, final Object value) {
        checkArgument(!Strings.isNullOrEmpty(key), "null/empty key");
        checkArgument(value != null, "null value");
        this.memcacheDataSource.getMemcachedClient().set(this.prefix + key, expiry, value);
    }

    @Override
    public void delete(final String key) {
        checkArgument(!Strings.isNullOrEmpty(key), "null/empty key");
        this.memcacheDataSource.getMemcachedClient().delete(this.prefix + key);
    }
}
